package thyyxxk.webserver.dao.his.zygl;

import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;
import thyyxxk.webserver.entity.zygl.ZyConfig;

public interface ZyConfigMapper {

    /**
     * 查询住院配置表信息
     * @return
     */
    @Select(" select * from zy_config where item_no = 1")
    ZyConfig selectZyConfig();


    /**
     * 更新住院号
     * @param inpatientNo
     * @param newInpatientNo
     * @return
     */
    @Update("update zy_config set inpatient_no =#{newInpatientNo} where item_no =1 and inpatient_no =#{inpatientNo} ")
    int updateInpatientNo(@Param("inpatientNo") Integer inpatientNo, @Param("newInpatientNo") Integer newInpatientNo);


    /**
     * 更新家床号码
     * @param jcNo
     * @param newJcNo
     * @return
     */
    @Update("update zy_config set jc_no =#{newJcNo} where item_no =1 and jc_no =#{jcNo} ")
    int updateJcNo(@Param("jcNo") Integer jcNo, @Param("newJcNo") Integer newJcNo);


    /**
     * 更新住院流水号
     * @param zySerialNo
     * @param newZySerialNo
     * @return
     */
    @Update("update zy_config set zy_serial_no =#{newZySerialNo} where item_no =1 and zy_serial_no =#{zySerialNo} ")
    int updateZySerialNo(@Param("zySerialNo") Integer zySerialNo, @Param("newZySerialNo") Integer newZySerialNo);

    /**
     * 更新收费编码
     * @param chargeCode
     * @param newChargeCode
     * @return
     */
    @Update("update zy_config set charge_code =#{newChargeCode} where item_no =1 and charge_code =#{chargeCode} ")
    int updateChargeCode(@Param("chargeCode") Integer chargeCode, @Param("newChargeCode") Integer newChargeCode);
    @Update(" update zy_config set del_no =#{newDelNo} where item_no =1 and del_no =#{delNo} ")
    int updateDelNo(@Param("delNo") Integer delNo, @Param("newDelNo") Integer newDelNo);
}
